/* Nessus Attack Scripting Language 
 *
 * Copyright (C) 2002 - 2003 Michel Arboi and Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison and Michel Arboi
 * give permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 *
 */
#ifndef NASL_VAR_H_INCLUDED
#define NASL_VAR_H_INCLUDED

enum {
  VAR2_UNDEF = 0,
  VAR2_INT,
  VAR2_STRING,
  VAR2_DATA,
  VAR2_ARRAY
};

#define VAR_NAME_HASH	17

typedef struct st_nasl_var {
  int		var_type;

  char		*var_name;
  int		var_num;
  int		var_size;
  union {
    char		*str_val; /* character string */
    int			i_val;	/* integer */
    struct st_nasl_var	**a_val;	/* array */
  } v;

  struct st_nasl_var	*next_var; /* next variable with same name hash */
} nasl_var;

typedef struct {
  nasl_var	**a;		/* array */
  int		i;		/* index */
  nasl_var	*v;		/* current variable */
} nasl_iterator;

tree_cell*	nasl_affect(tree_cell*, tree_cell*);

void		clear_var(nasl_var*);
const char*	var2str(nasl_var*);
const char*	get_var_name(nasl_var*);

nasl_var*	nasl_get_var_by_num(nasl_var**, int, int);

nasl_iterator	nasl_array_iterator(tree_cell*);
tree_cell*	nasl_iterate_array(nasl_iterator*);
void		add_var_to_list(nasl_var**, int, const nasl_var*);

#endif
